"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const probot_1 = require("probot");
const sentryApp = require("probot/lib/apps/sentry");
const logRequestErrors = require("probot/lib/middleware/log-request-errors");
const private_key_1 = require("probot/lib/private-key");
const landing_page_1 = require("./landing-page");
const utils_1 = require("./utils");
const options = {
    cert: String(private_key_1.findPrivateKey()),
    id: Number(process.env.APP_ID),
    port: 3000,
    secret: process.env.WEBHOOK_SECRET,
};
// tslint:disable-next-line:variable-name
const _createProbotAndLoadApplication = (applicationFn) => {
    const probot = probot_1.createProbot(options);
    // Log all unhandled rejections
    process.on("unhandledRejection", probot.errorHandler);
    const application = probot.load(applicationFn);
    probot.load(sentryApp);
    probot.server.use(logRequestErrors);
    application
        .route("/")
        .get("/", async (request, response) => {
        const name = await utils_1.fetchAppName(application);
        response.statusCode = 200;
        response.end(landing_page_1.default(name));
    });
    return { application, probot };
};
exports._createProbotAndLoadApplication = _createProbotAndLoadApplication;
/**
 * Starts the given application function.
 * To be called in a file to be built by @now/node-server.
 *
 * @param applicationFn - The function corresponding to this GitHub App.
 */
const start = (applicationFn) => {
    const { probot } = _createProbotAndLoadApplication(applicationFn);
    return new Promise(resolve => {
        const server = probot.server.listen(options.port, () => {
            const { port } = server.address();
            probot.logger.info(`Listening on http://localhost:${port}`);
            resolve({ port, stop: server.close.bind(server) });
        });
    });
};
exports.start = start;
